==> ToolChain_STM32_1.0.49.tar.bz: ToolChain_STM32_1.0.49/CommonLibraries/ttc_task.c <==
/*{ ttc_task.c ***********************************************
 
 * Written by Gregor Rebel 2010-2012
 *
 * Scheduler and architecture independent multitasking support.
 * 
}*/
#include "ttc_task.h"
#ifdef EXTENSION_300_scheduler_free_rtos
void vApplicationMallocFailedHook(void) {
    /* Called if a call to pvPortMalloc() fails because there is insufficient
       free memory available in the FreeRTOS heap.  pvPortMalloc() is called
       internally by FreeRTOS API functions that create tasks, queues, software
       timers, and semaphores.  The size of the FreeRTOS heap is set by the
       configTOTAL_HEAP_SIZE configuration constant in FreeRTOSConfig.h. */
    Assert(0, ec_Malloc);
}
void vApplicationStackOverflowHook( xTaskHandle pxTask, signed char *pcTaskName ) {
    ( void ) pcTaskName;
    ( void ) pxTask;

    /* Run time stack overflow checking is performed if
       configconfigCHECK_FOR_STACK_OVERFLOW is defined to 1 or 2.  This hook
       function is called if a stack overflow is detected. */
    Assert(0, ec_None);
}
#endif

void programCalibrateUSleep() {
  
#ifdef TTC_LED1
  ttc_Port_t Port_LED1;
  ttc_gpio_init_variable(&Port_LED1, TTC_LED1, tgm_output_push_pull);
  
  while (1) {
    ttc_gpio_set_variable(&Port_LED1);
    uSleep(1000);           // 1ms high time
    ttc_gpio_clr_variable(&Port_LED1);

    uSleep(100);            // 100us low time

  }
#else
  Assert(0, ec_UNKNOWN); // programCalibrateUSleep() requires definition of TTC_LED1! (E.g.; #define TTC_LED1 PA7)
#endif

}
void mSleep(u32_t Delay) {

    for (;Delay > 0; Delay--)
      uSleep(1000);
}
void uSleep(u32_t Delay) {

    Delay *= configTICK_RATE_HZ; // smallest delay depends on tick rate <-- test setting via programCalibrateUSleep()
    Delay /= 1000000;

    while (Delay > 0xffff) { // split long delays into smaller ones
      #ifdef EXTENSION_300_scheduler_free_rtos
        vTaskDelay(Delay & 0xffff);
      #endif
      Delay -= 0xffff;
    }
    #ifdef EXTENSION_300_scheduler_free_rtos
      vTaskDelay(Delay);
    #endif
}
void ttc_task_msleep(u32_t Delay) { mSleep(Delay); }
void ttc_task_usleep(u32_t Delay) { uSleep(Delay); }
BOOL ttc_task_create( void TaskFunction(void*), const char* TaskName, u16_t StackSize, void* Argument, u8_t Priority, TaskHandle_t* Handle) {

  #ifdef EXTENSION_300_scheduler_free_rtos
    if (Priority >= configMAX_PRIORITIES)
        Priority = configMAX_PRIORITIES - 1;

    #define IMPLEMENTATION_ttc_task_create
    if ( xTaskCreate( (pdTASK_CODE) TaskFunction,
                      (const signed char *) TaskName,
                      (unsigned short ) StackSize,
                      Argument,
                      (Base_t) Priority,
                      (void*) Handle
                      )
         ) return TRUE;

    *Handle = NULL;
    return FALSE;
  #endif

  // no scheduler available: use plain function call
  #ifndef IMPLEMENTATION_ttc_task_create
    (void) TaskFunction;
    (void) TaskName;
    (void) StackSize;
    (void) Argument;
    (void) Priority;
    (void) Handle;

    #warning ttc_task_create() will use plain function calls
    TaskFunction(Argument);
    return FALSE;
  #endif
}
void ttc_task_yield() {
#ifdef EXTENSION_300_scheduler_free_rtos
    taskYIELD();
#endif
}
inline void ttc_task_yield_isr() {
#ifdef EXTENSION_300_scheduler_free_rtos
    vPortYieldFromISR();
#endif
}
void _ttc_task_begin_criticalsection() {
#ifdef EXTENSION_300_scheduler_free_rtos
    portENTER_CRITICAL();
#endif
}
u8_t CountCriticalSection = 0;
void _ttc_task_begin_criticalsection2(void (*Owner)()) {
    static void (*LastOwner)() = NULL;


#ifdef EXTENSION_300_scheduler_free_rtos
    portENTER_CRITICAL();
#endif
    Assert(!CountCriticalSection, ec_InvalidArgument);
    CountCriticalSection++;
    LastOwner = Owner;
}
void ttc_task_end_criticalsection() {
    CountCriticalSection--;

#ifdef EXTENSION_300_scheduler_free_rtos
    portEXIT_CRITICAL();
#endif
}
Base_t ttc_task_get_tick_count() {
#ifdef EXTENSION_300_scheduler_free_rtos

#if TARGET_DATA_WIDTH == 32
    // direct access only allowed for 32-bit architectures

    return (1000000 / configTICK_RATE_HZ) * xTickCount;

#else
    return (1000000 / configTICK_RATE_HZ) * xTaskGetTickCount();
#endif

#endif

    return 0;
}
Base_signed_t ttc_task_check_stack() {
#if defined(EXTENSION_300_scheduler_free_rtos) && defined(INCLUDE_uxTaskGetStackHighWaterMark)
    volatile int StackBytesFree = uxTaskGetStackHighWaterMark(NULL);
    Assert(StackBytesFree > 0, ec_Malloc); // stack is full: stop immediately
#else
    volatile int StackBytesFree = 1; // dummy value that is always > 0
#endif


    return StackBytesFree; // <-- place your breakpoint right here!
}
void ttc_task_start_scheduler() {
#ifdef EXTENSION_300_scheduler_free_rtos
    vTaskStartScheduler(); // FreeRTOS-scheduler (never returns)
#endif
}
void ttc_task_resume(TaskHandle_t Handle) {
    Assert_Task(Handle, ec_InvalidArgument);

#ifdef EXTENSION_300_scheduler_free_rtos
    vTaskResume(Handle);
#endif
}
BOOL ttc_task_resume_isr(TaskHandle_t Handle) {
    Assert_Task(Handle, ec_InvalidArgument);

#ifdef EXTENSION_300_scheduler_free_rtos
    return xTaskResumeFromISR(Handle);
#endif
    return FALSE;
}
void ttc_task_suspend(TaskHandle_t Handle) {

#ifdef EXTENSION_300_scheduler_free_rtos
    vTaskSuspend(Handle);
#endif
}

==> ToolChain_STM32_1.0.51.tar.bz: ToolChain_STM32_1.0.51/CommonLibraries/ttc_task.c <==
/*{ ttc_task.c ***********************************************
 
 * Written by Gregor Rebel 2010-2012
 *
 * Scheduler and architecture independent multitasking support.
 * 
}*/
#include "ttc_task.h"
#ifdef EXTENSION_300_scheduler_free_rtos
void vApplicationMallocFailedHook(void) {
    /* Called if a call to pvPortMalloc() fails because there is insufficient
       free memory available in the FreeRTOS heap.  pvPortMalloc() is called
       internally by FreeRTOS API functions that create tasks, queues, software
       timers, and semaphores.  The size of the FreeRTOS heap is set by the
       configTOTAL_HEAP_SIZE configuration constant in FreeRTOSConfig.h. */
    Assert(0, ec_Malloc);
}
void vApplicationStackOverflowHook( xTaskHandle pxTask, signed char *pcTaskName ) {
    ( void ) pcTaskName;
    ( void ) pxTask;

    /* Run time stack overflow checking is performed if
       configconfigCHECK_FOR_STACK_OVERFLOW is defined to 1 or 2.  This hook
       function is called if a stack overflow is detected. */
    Assert(0, ec_None);
}
#endif

// increased by _ttc_task_begin_criticalsection2(); decreased by ttc_task_end_criticalsection2()
s16_t ttc_task_CountCriticalSection = 0;

         void programCalibrateUSleep() {
  
#ifdef TTC_LED1
  ttc_Port_t Port_LED1;
  ttc_gpio_init_variable(&Port_LED1, TTC_LED1, tgm_output_push_pull);
  
  while (1) {
    ttc_gpio_set_variable(&Port_LED1);
    uSleep(1000);           // 1ms high time
    ttc_gpio_clr_variable(&Port_LED1);

    uSleep(100);            // 100us low time

  }
#else
  Assert(0, ec_UNKNOWN); // programCalibrateUSleep() requires definition of TTC_LED1! (E.g.; #define TTC_LED1 PA7)
#endif

}
         void mSleep(u32_t Delay) {

    for (;Delay > 0; Delay--)
      uSleep(1000);
}
         void uSleep(u32_t Delay) {

    Delay *= configTICK_RATE_HZ; // smallest delay depends on tick rate <-- test setting via programCalibrateUSleep()
    Delay /= 1000000;

    while (Delay > 0xffff) { // split long delays into smaller ones
      #ifdef EXTENSION_300_scheduler_free_rtos
        vTaskDelay(Delay & 0xffff);
      #endif
      Delay -= 0xffff;
    }
    #ifdef EXTENSION_300_scheduler_free_rtos
      vTaskDelay(Delay);
    #endif
}
         void ttc_task_msleep(u32_t Delay) { mSleep(Delay); }
         void ttc_task_usleep(u32_t Delay) { uSleep(Delay); }
         BOOL ttc_task_create( void TaskFunction(void*), const char* TaskName, u16_t StackSize, void* Argument, u8_t Priority, TaskHandle_t* Handle) {

  #ifdef EXTENSION_300_scheduler_free_rtos
    if (Priority >= configMAX_PRIORITIES)
        Priority = configMAX_PRIORITIES - 1;

    #define IMPLEMENTATION_ttc_task_create
    if ( xTaskCreate( (pdTASK_CODE) TaskFunction,
                      (const signed char *) TaskName,
                      (unsigned short ) StackSize,
                      Argument,
                      (Base_t) Priority,
                      (void*) Handle
                      )
         ) return TRUE;

    *Handle = NULL;
    return FALSE;
  #endif

  // no scheduler available: use plain function call
  #ifndef IMPLEMENTATION_ttc_task_create
    (void) TaskFunction;
    (void) TaskName;
    (void) StackSize;
    (void) Argument;
    (void) Priority;
    (void) Handle;

    #warning ttc_task_create() will use plain function calls
    TaskFunction(Argument);
    return FALSE;
  #endif
}
         void ttc_task_yield() {
#ifdef EXTENSION_300_scheduler_free_rtos
    taskYIELD();
#endif
}
  inline void ttc_task_yield_isr() {
#ifdef EXTENSION_300_scheduler_free_rtos
    vPortYieldFromISR();
#endif
}
         void ttc_task_end_criticalsection() {

#ifdef EXTENSION_300_scheduler_free_rtos
    portEXIT_CRITICAL();
#endif
}
         void ttc_task_end_criticalsection2() {
    ttc_task_CountCriticalSection--;
    Assert(ttc_task_CountCriticalSection >= 0, ec_InvalidImplementation);

#ifdef EXTENSION_300_scheduler_free_rtos
    portEXIT_CRITICAL();
#endif
}
       Base_t ttc_task_get_tick_count() {
#ifdef EXTENSION_300_scheduler_free_rtos

#if TARGET_DATA_WIDTH == 32
    // direct access only allowed for 32-bit architectures

    return (1000000 / configTICK_RATE_HZ) * xTickCount;

#else
    return (1000000 / configTICK_RATE_HZ) * xTaskGetTickCount();
#endif

#endif

    return 0;
}
Base_signed_t ttc_task_check_stack() {
#if defined(EXTENSION_300_scheduler_free_rtos) && defined(INCLUDE_uxTaskGetStackHighWaterMark)
    volatile int StackBytesFree = uxTaskGetStackHighWaterMark(NULL);
    Assert(StackBytesFree > 0, ec_Malloc); // stack is full: stop immediately
#else
    volatile int StackBytesFree = 1; // dummy value that is always > 0
#endif


    return StackBytesFree; // <-- place your breakpoint right here!
}
         void ttc_task_start_scheduler() {
#ifdef EXTENSION_300_scheduler_free_rtos
    vTaskStartScheduler(); // FreeRTOS-scheduler (never returns)
#endif
}
         void ttc_task_resume(TaskHandle_t Handle) {
    Assert_Task(Handle, ec_InvalidArgument);

#ifdef EXTENSION_300_scheduler_free_rtos
    vTaskResume(Handle);
#endif
}
         BOOL ttc_task_resume_isr(TaskHandle_t Handle) {
    Assert_Task(Handle, ec_InvalidArgument);

#ifdef EXTENSION_300_scheduler_free_rtos
    return xTaskResumeFromISR(Handle);
#endif
    return FALSE;
}
         void ttc_task_suspend(TaskHandle_t Handle) {

#ifdef EXTENSION_300_scheduler_free_rtos
    vTaskSuspend(Handle);
#endif
}

         void _ttc_task_begin_criticalsection() {
#ifdef EXTENSION_300_scheduler_free_rtos
    portENTER_CRITICAL();
#endif
}
         void _ttc_task_begin_criticalsection2(void (*Owner)()) {
    static void (*LastOwner)() = NULL;

#ifdef EXTENSION_300_scheduler_free_rtos
    portENTER_CRITICAL();
#endif
    Assert(ttc_task_CountCriticalSection < 1000, ec_InvalidImplementation);
    ttc_task_CountCriticalSection++;
    LastOwner = Owner;
}
